aboutsummaryrefslogtreecommitdiff
path: root/examples/stm32/f1/stm32-h103/usb_iap/usbiap.c
diff options
context:
space:
mode:
authorchrysn2012-03-02 23:59:52 +0100
committerchrysn2012-03-02 23:59:52 +0100
commit563586c072c38fe1d0706bfc96dae33773f1dda7 (patch)
tree95ed81a5862e8ba5bfcdf1e908bb91cbb7f51b23 /examples/stm32/f1/stm32-h103/usb_iap/usbiap.c
parente388056fda84a5c85430f5a31a4cfe3af3f2e35f (diff)
parent43561de3297b88d68753cb4625d6dc48bfb43d71 (diff)
Merge branch 'master' into efm32
Diffstat (limited to 'examples/stm32/f1/stm32-h103/usb_iap/usbiap.c')
-rw-r--r--examples/stm32/f1/stm32-h103/usb_iap/usbiap.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/examples/stm32/f1/stm32-h103/usb_iap/usbiap.c b/examples/stm32/f1/stm32-h103/usb_iap/usbiap.c
index 410a1a1..3cf7044 100644
--- a/examples/stm32/f1/stm32-h103/usb_iap/usbiap.c
+++ b/examples/stm32/f1/stm32-h103/usb_iap/usbiap.c
@@ -3,18 +3,18 @@
*
* Copyright (C) 2010 Gareth McMullin <gareth@blacksphere.co.nz>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
*
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
#include <string.h>
@@ -149,7 +149,7 @@ static void usbdfu_getstatus_complete(struct usb_setup_data *req)
u32 baseaddr = prog.addr + ((prog.blocknum - 2) *
dfu_function.wTransferSize);
for (i = 0; i < prog.len; i += 2)
- flash_program_half_word(baseaddr + i,
+ flash_library_half_word(baseaddr + i,
*(u16 *)(prog.buf + i));
}
flash_lock();
@@ -3,18 +3,18 @@
* Copyright (C) 2010 Gareth McMullin <gareth@blacksphere.co.nz>
*
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
+ * This library is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
@@ -3,18 +3,18 @@
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the